'' =================================================================================================
''
''   File....... jm_servo8_ez_demo.spin
''   Purpose.... Demonstrates my new, full-featured servo driver
''   Author..... Jon "JonnyMac" McPhalen (aka Jon Williams)
''               Copyright (c) 2011 Jon McPhalen
''               -- see below for terms of use
''   E-mail..... jon@jonmcphalen.com
''   Started.... 
''   Updated.... 19 JUL 2011
''
'' =================================================================================================


con

  _clkmode = xtal1 + pll16x
' _xinfreq = 5_000_000                                          ' use 5MHz crystal
  _xinfreq = 6_250_000                                          ' use 6.25MHz crystal

  CLK_FREQ = ((_clkmode - xtal1) >> 6) * _xinfreq
  MS_001   = CLK_FREQ / 1_000
  US_001   = CLK_FREQ / 1_000_000


con

  RX1 = 31
  TX1 = 30
  SDA = 29
  SCL = 28

  OEn = 27                                                      ' output enable for HC-8+                     

  CH7 = 15                                                      ' HC-8+ outputs
  CH6 = 14
  CH5 = 13
  CH4 = 12
  CH3 = 11
  CH2 = 10
  CH1 =  9
  CH0 =  8


con

   #1, HOME, GOTOXY, #8, BKSP, TAB, LF, CLREOL, CLRDN, CR       ' PST formmatting control
  #14, GOTOX, GOTOY, CLS


obj

  servos : "jm_servo8_ez"                                       ' servo driver
  term   : "fullduplexserial"                                   ' serial for terminal


var


pub main 

  servos.start(8, CH0)                                          ' start servo driver
  low(OEn)                                                      ' enable HC-8+ outputs

  term.start(RX1, TX1, %0000, 115_200)
  pause(1)

  term.str(string(CLS, "Servo Demo", CR, CR))

  term.str(string("Position -> 0.6ms", CR))
  servos.set_all(0_600, 0)                                      ' move now (no speed control)
  pause(2_000)

  term.str(string("Low-speed wag", CR)) 
  servos.set_pos(0, 2_400, 50)                                  ' slowest speed (50us/s)
  servos.wait(0)                                                ' let move finish
  servos.set_pos(0, 0_600, 50)
  servos.wait(0)

  repeat
    term.str(string("Position -> 2.4ms (in ~2s)", CR))
    servos.move_all(2_400, 2_000)                               ' pos in us, timing in ms
    servos.wait(0)                                              ' let move finish

    term.str(string("Position -> 1.0ms (in ~10s)", CR))   
    servos.move_all(0_600, 10_000)                
    servos.wait(0)
        

pub pause(ms) | t

'' Delay program ms milliseconds

  t := cnt - 1088                                               ' sync with system counter
  repeat (ms #> 0)                                              ' delay must be > 0
    waitcnt(t += MS_001)


pub high(pin)

'' Makes pin output and high

  outa[pin] := 1
  dira[pin] := 1


pub low(pin)

'' Makes pin output and low

  outa[pin] := 0
  dira[pin] := 1
  

pub input(pin)

'' Makes pin input and returns current state

  dira[pin] := 0

  return ina[pin]
  
 
dat

{{

  Terms of Use: MIT License

  Permission is hereby granted, free of charge, to any person obtaining a copy of this
  software and associated documentation files (the "Software"), to deal in the Software
  without restriction, including without limitation the rights to use, copy, modify,
  merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
  permit persons to whom the Software is furnished to do so, subject to the following
  conditions:

  The above copyright notice and this permission notice shall be included in all copies
  or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
  PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
  CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
  OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

}}